==> plugin-android-3.0.2-sources.jar: com/zoyi/channel/plugin/android/activity/chat/viewholder/SendingMessageHolder.java <==
package com.zoyi.channel.plugin.android.activity.chat.viewholder;

import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.TextView;

import com.zoyi.channel.plugin.android.R;
import com.zoyi.channel.plugin.android.activity.chat.listener.OnSendingMessageClickListener;
import com.zoyi.channel.plugin.android.activity.chat.model.SendingMessageItem;
import com.zoyi.channel.plugin.android.activity.chat.type.MessageType;
import com.zoyi.channel.plugin.android.util.UIUtils;
import com.zoyi.channel.plugin.android.view.layout.MaskableFrameLayout;
import com.zoyi.com.bumptech.glide.Glide;

/**
 * Created by mika on 2017. 3. 2..
 */
public class SendingMessageHolder extends BaseMessageHolder implements View.OnClickListener {

  View root;

  View resendLocalContentButton;

  View localTextLayout;
  View localTextContentLayout;
  View localTextContentBackground;
  TextView localMessageText;

  View localImageLayout;
  MaskableFrameLayout localImageLoadingLayout;
  ImageView imagePlaceholder;
  ImageView imageLoading;
  View localImageProgressView, localImageUploadFailedView;

  private OnSendingMessageClickListener listener;
  private SendingMessageItem item;

  public static SendingMessageHolder newInstance(
      ViewGroup parent,
      MessageType messageType,
      OnSendingMessageClickListener listener) {
    return new SendingMessageHolder(getItemView(parent, messageType), messageType, listener);
  }
  public SendingMessageHolder(
      View itemView,
      MessageType messageType,
      OnSendingMessageClickListener listener) {
    super(itemView, messageType);

    this.listener = listener;

    root = itemView.findViewById(R.id.ch_message_content_loading);

    localMessageText = itemView.findViewById(R.id.ch_text_local_message);
    localTextLayout = itemView.findViewById(R.id.ch_layout_local_message_text);
    localTextContentLayout = itemView.findViewById(R.id.ch_layout_local_message_content);
    localTextContentBackground = itemView.findViewById(R.id.ch_view_local_message_content_top);

    imagePlaceholder = itemView.findViewById(R.id.image_placeholder);
    imageLoading = itemView.findViewById(R.id.image_loading);

    localImageLayout = itemView.findViewById(R.id.ch_layout_local_message_image_content);
    localImageLoadingLayout = itemView.findViewById(R.id.ch_layout_local_message_image);
    localImageProgressView = itemView.findViewById(R.id.progress_upload);
    localImageUploadFailedView = itemView.findViewById(R.id.image_upload_failed);

    resendLocalContentButton = itemView.findViewById(R.id.ch_button_local_message_resend);
    resendLocalContentButton.setOnClickListener(this);
  }

  public void bind(SendingMessageItem item, int messageColor, int messageBackgroundColor) {
    super.bind(null, item.getType(), true);
    this.item = item;
    root.setVisibility(View.VISIBLE);
    guestMessageTextLayout.setVisibility(View.GONE);
    guestMessageTime.setVisibility(View.GONE);
    localImageLayout.setVisibility(View.GONE);
    localTextLayout.setVisibility(View.GONE);
    resendLocalContentButton.setVisibility(UIUtils.getVisible(!item.isSending(), true));

    if (item.isImage()) {
      setLocalImageMessage(item);
    } else {
      setLocalTextMessage(item, messageColor, messageBackgroundColor);
    }
  }

  private void setLocalImageMessage(SendingMessageItem item) {
    Glide.with(itemView.getContext())
        .load(item.getString())
        .asBitmap()
        .dontAnimate()
        .centerCrop()
        .into(imageLoading);

    imagePlaceholder.setVisibility(View.GONE);

    localImageLayout.setVisibility(View.VISIBLE);
    localImageLoadingLayout.setVisibility(View.VISIBLE);
    localImageProgressView.setVisibility(UIUtils.getVisible(item.isSending(), true));
    localImageUploadFailedView.setVisibility(UIUtils.getVisible(!item.isSending(), true));
  }

  private void setLocalTextMessage(SendingMessageItem item, int messageColor, int messageBackgroundColor) {
    localTextLayout.setVisibility(View.VISIBLE);
    localMessageText.setText(item.getString());
    localMessageText.setTextColor(messageColor);
    localMessageText.setBackgroundColor(messageBackgroundColor);
    localTextContentBackground.setBackgroundColor(messageBackgroundColor);
  }

  @Override
  public void onClick(View v) {
    if (listener != null && item != null) {
      listener.sendingMessageClicked(item);
    }
  }
}

==> plugin-android-3.1.1-sources.jar: com/zoyi/channel/plugin/android/activity/chat/viewholder/SendingMessageHolder.java <==
package com.zoyi.channel.plugin.android.activity.chat.viewholder;

import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.TextView;

import com.zoyi.channel.plugin.android.R;
import com.zoyi.channel.plugin.android.activity.chat.listener.OnSendingMessageClickListener;
import com.zoyi.channel.plugin.android.activity.chat.model.SendingMessageItem;
import com.zoyi.channel.plugin.android.activity.chat.type.MessageType;
import com.zoyi.channel.plugin.android.util.UIUtils;
import com.zoyi.channel.plugin.android.view.layout.CHTextView;
import com.zoyi.channel.plugin.android.view.layout.MaskableFrameLayout;
import com.zoyi.com.bumptech.glide.Glide;

/**
 * Created by mika on 2017. 3. 2..
 */
public class SendingMessageHolder extends BaseMessageHolder implements View.OnClickListener {

  View root;

  View resendLocalContentButton;

  View localTextLayout;
  View localTextContentLayout;
  View localTextContentBackground;
  CHTextView localMessageText;

  View localImageLayout;
  MaskableFrameLayout localImageLoadingLayout;
  ImageView imagePlaceholder;
  ImageView imageLoading;
  View localImageProgressView, localImageUploadFailedView;

  private OnSendingMessageClickListener listener;
  private SendingMessageItem item;

  public static SendingMessageHolder newInstance(
      ViewGroup parent,
      MessageType messageType,
      OnSendingMessageClickListener listener) {
    return new SendingMessageHolder(getItemView(parent, messageType), messageType, listener);
  }
  public SendingMessageHolder(
      View itemView,
      MessageType messageType,
      OnSendingMessageClickListener listener) {
    super(itemView, messageType);

    this.listener = listener;

    root = itemView.findViewById(R.id.ch_message_content_loading);

    localMessageText = itemView.findViewById(R.id.ch_text_local_message);
    localTextLayout = itemView.findViewById(R.id.ch_layout_local_message_text);
    localTextContentLayout = itemView.findViewById(R.id.ch_layout_local_message_content);
    localTextContentBackground = itemView.findViewById(R.id.ch_view_local_message_content_top);

    imagePlaceholder = itemView.findViewById(R.id.image_placeholder);
    imageLoading = itemView.findViewById(R.id.image_loading);

    localImageLayout = itemView.findViewById(R.id.ch_layout_local_message_image_content);
    localImageLoadingLayout = itemView.findViewById(R.id.ch_layout_local_message_image);
    localImageProgressView = itemView.findViewById(R.id.progress_upload);
    localImageUploadFailedView = itemView.findViewById(R.id.image_upload_failed);

    resendLocalContentButton = itemView.findViewById(R.id.ch_button_local_message_resend);
    resendLocalContentButton.setOnClickListener(this);
  }

  public void bind(SendingMessageItem item, int messageColor, int messageBackgroundColor) {
    super.bind(null, item.getType(), true);
    this.item = item;
    root.setVisibility(View.VISIBLE);
    guestMessageTextLayout.setVisibility(View.GONE);
    guestMessageTime.setVisibility(View.GONE);
    localImageLayout.setVisibility(View.GONE);
    localTextLayout.setVisibility(View.GONE);
    resendLocalContentButton.setVisibility(UIUtils.getVisible(!item.isSending(), true));

    if (item.isImage()) {
      setLocalImageMessage(item);
    } else {
      setLocalTextMessage(item, messageColor, messageBackgroundColor);
    }
  }

  private void setLocalImageMessage(SendingMessageItem item) {
    Glide.with(itemView.getContext())
        .load(item.getString())
        .asBitmap()
        .dontAnimate()
        .centerCrop()
        .into(imageLoading);

    imagePlaceholder.setVisibility(View.GONE);

    localImageLayout.setVisibility(View.VISIBLE);
    localImageLoadingLayout.setVisibility(View.VISIBLE);
    localImageProgressView.setVisibility(UIUtils.getVisible(item.isSending(), true));
    localImageUploadFailedView.setVisibility(UIUtils.getVisible(!item.isSending(), true));
  }

  private void setLocalTextMessage(SendingMessageItem item, int messageColor, int messageBackgroundColor) {
    localTextLayout.setVisibility(View.VISIBLE);
    localMessageText.setText(item.getString());
    localMessageText.setTextColor(messageColor);
    localMessageText.setBackgroundColor(messageBackgroundColor);
    localTextContentBackground.setBackgroundColor(messageBackgroundColor);
  }

  @Override
  public void onClick(View v) {
    if (listener != null && item != null) {
      listener.sendingMessageClicked(item);
    }
  }
}
